@@ -44,7 +44,8 @@ class __TwigTemplate_55f91962626a7a309a423fa01c946f55 extends Template
 <html>
 ";
         // line 3
-        yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Default/head.html.twig", ["headerTitle" => ((        $this->unwrap()->hasBlock("headerTitle", $context, $blocks)) ? ("Cause Buzz1") : ("Cause Buzz1")), "pageTitle" => ((        $this->unwrap()->hasBlock("pageTitle", $context, $blocks)) ? ("Cause Buzz") : ("Cause Buzz"))]);
+        yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Default/head.html.twig", ["headerTitle" => ((        $this->unwrap()->hasBlock("headerTitle", $context, $blocks)) ? (        $this->unwrap()->renderBlock("headerTitle", $context, $blocks)) : (((        // line 4
+array_key_exists("headerTitle", $context)) ? (Twig\Extension\CoreExtension::default((isset($context["headerTitle"]) || array_key_exists("headerTitle", $context) ? $context["headerTitle"] : (function () { throw new RuntimeError('Variable "headerTitle" does not exist.', 4, $this->source); })()), "")) : ("")))), "pageTitle" => ((        $this->unwrap()->hasBlock("pageTitle", $context, $blocks)) ? ("Cause Buzz") : ("Cause Buzz"))]);
         // line 7
         yield "
     <body class=\"header-fixed\">
@@ -192,7 +193,7 @@ class __TwigTemplate_55f91962626a7a309a423fa01c946f55 extends Template
      */
     public function getDebugInfo(): array
     {
-        return array (  167 => 40,  160 => 39,  150 => 65,  148 => 62,  144 => 61,  140 => 59,  126 => 47,  124 => 46,  118 => 42,  116 => 39,  106 => 32,  102 => 31,  92 => 24,  85 => 20,  79 => 17,  75 => 16,  71 => 15,  67 => 14,  63 => 13,  59 => 12,  54 => 10,  49 => 7,  47 => 3,  43 => 1,);
+        return array (  168 => 40,  161 => 39,  151 => 65,  149 => 62,  145 => 61,  141 => 59,  127 => 47,  125 => 46,  119 => 42,  117 => 39,  107 => 32,  103 => 31,  93 => 24,  86 => 20,  80 => 17,  76 => 16,  72 => 15,  68 => 14,  64 => 13,  60 => 12,  55 => 10,  50 => 7,  48 => 4,  47 => 3,  43 => 1,);
     }
 
     public function getSourceContext(): Source
